@@ -4,15 +4,14 @@ https://www.w3.org/TR/shacl/#sparql-constraint-components
 """
 import typing
 
-from typing import Any, Dict, List, Set, Tuple, Type, Union
+from typing import Dict, List, Tuple, Type, Union
 
 import rdflib
 
-from pyshacl.constraints.constraint_component import ConstraintComponent
-from pyshacl.constraints.sparql.sparql_based_constraints import SPARQLQueryHelper
-from pyshacl.consts import SH, RDF_type, SH_ask, SH_message, SH_parameter, SH_path, SH_select
+from pyshacl.constraints.constraint_component import ConstraintComponent, CustomConstraintComponent
+from pyshacl.consts import SH, RDF_type, SH_ask, SH_ConstraintComponent, SH_message, SH_select
 from pyshacl.errors import ConstraintLoadError, ValidationFailure
-from pyshacl.parameter import SHACLParameter
+from pyshacl.helper import get_query_helper_cls
 from pyshacl.pytypes import GraphLike
 
 
@@ -21,12 +20,6 @@ if typing.TYPE_CHECKING:
     from pyshacl.shapes_graph import ShapesGraph
 
 
-SH_nodeValidator = SH.term('nodeValidator')
-SH_propertyValidator = SH.term('propertyValidator')
-SH_validator = SH.term('validator')
-SH_optional = SH.term('optional')
-
-SH_ConstraintComponent = SH.term('ConstraintComponent')
 SH_SPARQLSelectValidator = SH.term('SPARQLSelectValidator')
 SH_SPARQLAskValidator = SH.term('SPARQLAskValidator')
 
@@ -46,6 +39,7 @@ class BoundShapeValidatorComponent(ConstraintComponent):
         self.constraint = constraint
         self.validator = validator
         params = constraint.parameters
+        SPARQLQueryHelper = get_query_helper_cls()
         self.query_helper = SPARQLQueryHelper(
             self.shape, validator.node, validator.query_text, params, messages=validator.messages
         )
@@ -55,7 +49,7 @@ class BoundShapeValidatorComponent(ConstraintComponent):
     @classmethod
     def constraint_parameters(cls):
         # TODO:coverage: this is never used for this constraint?
-        return [SH_validator, SH_nodeValidator, SH_propertyValidator]
+        return []
 
     @classmethod
     def constraint_name(cls):
@@ -66,6 +60,9 @@ class BoundShapeValidatorComponent(ConstraintComponent):
         # TODO:coverage: this is never used for this constraint?
         return SH_ConstraintComponent
 
+    def make_generic_messages(self, datagraph: GraphLike, focus_node, value_node) -> List[rdflib.Literal]:
+        return [rdflib.Literal("Parameterised SHACL Query generated constraint validation reports.")]
+
     def evaluate(self, target_graph: GraphLike, focus_value_nodes: Dict, _evaluation_path: List):
         """
         :type focus_value_nodes: dict
@@ -73,7 +70,7 @@ class BoundShapeValidatorComponent(ConstraintComponent):
         """
         reports = []
         non_conformant = False
-        extra_messages = self.query_helper.messages or None
+        extra_messages = self.constraint.messages or []
         rept_kwargs = {
             # TODO, determine if we need sourceConstraint here
             #  'source_constraint': self.validator.node,
@@ -87,22 +84,43 @@ class BoundShapeValidatorComponent(ConstraintComponent):
                 violations = self.validator.validate(f, value_nodes, target_graph, self.query_helper)
             except ValidationFailure as e:
                 raise e
-            if not self.shape.is_property_shape:
-                result_val = f
-            else:
-                result_val = None
-            for v in violations:
+            for val, vio in violations:
                 non_conformant = True
-                if isinstance(v, bool) and v is True:
-                    # TODO:coverage: No test for when violation is `True`
-                    rept = self.make_v_result(target_graph, f, value_node=result_val, **rept_kwargs)
-                elif isinstance(v, tuple):
-                    t, p, v = v
+                msg_args_map = self.query_helper.param_bind_map.copy()
+                msg_args_map.update({"this": f, "value": val})
+                if self.shape.is_property_shape:
+                    msg_args_map['path'] = self.shape.path()
+                self.query_helper.bind_messages(msg_args_map)
+                bound_messages = self.query_helper.bound_messages
+                # The DASH test suite likes _no_ value entry in the report if we're on a Property Shape.
+                report_val = val if not self.shape.is_property_shape else None
+                if isinstance(vio, bool):
+                    if vio is False:  # ASKValidator Result
+                        new_kwargs = rept_kwargs.copy()
+                        new_kwargs['extra_messages'].extend(bound_messages)
+                        rept = self.make_v_result(target_graph, f, value_node=report_val, **new_kwargs)
+                    else:  # SELECTValidator Failure
+                        raise ValidationFailure("Validation Failure generated by SPARQLConstraint.")
+                elif isinstance(vio, tuple):
+                    t, p, v = vio
+                    new_msg_args_map = msg_args_map.copy()
                     if v is None:
-                        v = result_val
-                    rept = self.make_v_result(target_graph, t or f, value_node=v, result_path=p, **rept_kwargs)
+                        v = report_val
+                    else:
+                        new_msg_args_map['value'] = v
+                    if p is not None:
+                        new_msg_args_map['path'] = p
+                    if t is not None:
+                        new_msg_args_map['this'] = t
+                    self.query_helper.bind_messages(new_msg_args_map)
+                    new_bound_msgs = self.query_helper.bound_messages
+                    new_kwargs = rept_kwargs.copy()
+                    new_kwargs['extra_messages'].extend(new_bound_msgs)
+                    rept = self.make_v_result(target_graph, t or f, value_node=v, result_path=p, **new_kwargs)
                 else:
-                    rept = self.make_v_result(target_graph, f, value_node=v, **rept_kwargs)
+                    new_kwargs = rept_kwargs.copy()
+                    new_kwargs['extra_messages'].extend(bound_messages)
+                    rept = self.make_v_result(target_graph, f, value_node=report_val, **new_kwargs)
                 reports.append(rept)
         return (not non_conformant), reports
 
@@ -188,6 +206,20 @@ class SPARQLConstraintComponentValidator(object):
         self.messages = message_nodes
         self.initialised = True
 
+    def make_messages(self, params_map=None):
+        if params_map is None:
+            return self.messages
+        ret_msgs = []
+        for m in self.messages:
+            this_m = m.value[:]
+            for a, v in params_map.items():
+                replace_me = "{$" + str(a) + "}"
+                if isinstance(v, rdflib.Literal):
+                    v = v.value
+                this_m = this_m.replace(replace_me, str(v))
+            ret_msgs.append(rdflib.Literal(this_m))
+        return ret_msgs
+
 
 class AskConstraintValidator(SPARQLConstraintComponentValidator):
     def __new__(cls, shacl_graph: 'ShapesGraph', node, *args, **kwargs):
@@ -227,7 +259,7 @@ class AskConstraintValidator(SPARQLConstraintComponentValidator):
         new_bind_vals = new_bind_vals or {}
         bind_vals = param_bind_vals.copy()
         bind_vals.update(new_bind_vals)
-        violations = []
+        violations = set()
         for v in value_nodes:
             if query_helper is None:
                 # TODO:coverage: No test for this case when query_helper is None
@@ -246,7 +278,7 @@ class AskConstraintValidator(SPARQLConstraintComponentValidator):
                 # TODO:coverage: Can this ever actually happen?
                 raise ValidationFailure("ASK Query did not return an askAnswer.")
             if answer is False:
-                violations.append(v)
+                violations.add((v, False))
         return violations
 
 
@@ -288,6 +320,7 @@ class SelectConstraintValidator(SPARQLConstraintComponentValidator):
         new_bind_vals = new_bind_vals or {}
         bind_vals = param_bind_vals.copy()
         bind_vals.update(new_bind_vals)
+        violations = set()
         for v in value_nodes:
             if query_helper is None:
                 # TODO:coverage: No test for this case when query_helper is None
@@ -301,133 +334,34 @@ class SelectConstraintValidator(SPARQLConstraintComponentValidator):
                 init_binds.update(bind_vals)
             results = target_graph.query(sparql_text, initBindings=init_binds)
             if not results or len(results.bindings) < 1:
-                return []
-            violations = set()
+                continue
             for r in results:
                 try:
                     p = r['path']
                 except KeyError:
                     p = None
                 try:
-                    v = r['value']
+                    v2 = r['value']
                 except KeyError:
-                    v = None
+                    v2 = None
                 try:
                     t = r['this']
                 except KeyError:
                     # TODO:coverage: No test for when result has no 'this' key
                     t = None
-                if p or v or t:
-                    violations.add((t, p, v))
+                if p or v2 or t:
+                    violations.add((v, (t, p, v2)))
                 else:
                     # TODO:coverage: No test for generic failure, when
                     #  'path' and 'value' and 'this' are not returned.
                     #  here 'failure' must exist
                     try:
-                        _ = r['failure']
-                        violations.add(True)
+                        f = r['failure']
+                        if f is True or (isinstance(f, rdflib.Literal) and f.value):
+                            violations.add((v, True))
                     except KeyError:
                         pass
-            return violations
-
-
-class CustomConstraintComponentFactory(object):
-    __slots__: Tuple = tuple()
-
-    def __new__(cls, shacl_graph: 'ShapesGraph', node):
-        self: List[Any] = list()
-        self.append(shacl_graph)
-        self.append(node)
-        optional_params = []
-        mandatory_params = []
-        param_nodes = set(shacl_graph.objects(node, SH_parameter))
-        if len(param_nodes) < 1:
-            # TODO:coverage: we don't have any tests for invalid constraints
-            raise ConstraintLoadError(
-                "A sh:ConstraintComponent must have at least one value for sh:parameter",
-                "https://www.w3.org/TR/shacl/#constraint-components-parameters",
-            )
-        for param_node in iter(param_nodes):
-            path_nodes = set(shacl_graph.objects(param_node, SH_path))
-            if len(path_nodes) < 1:
-                # TODO:coverage: we don't have any tests for invalid constraints
-                raise ConstraintLoadError(
-                    "A sh:ConstraintComponent parameter value must have at least one value for sh:path",
-                    "https://www.w3.org/TR/shacl/#constraint-components-parameters",
-                )
-            elif len(path_nodes) > 1:
-                # TODO:coverage: we don't have any tests for invalid constraints
-                raise ConstraintLoadError(
-                    "A sh:ConstraintComponent parameter value must have at most one value for sh:path",
-                    "https://www.w3.org/TR/shacl/#constraint-components-parameters",
-                )
-            path = next(iter(path_nodes))
-            parameter = SHACLParameter(shacl_graph, param_node, path=path, logger=None)  # pass in logger?
-            if parameter.optional:
-                optional_params.append(parameter)
-            else:
-                mandatory_params.append(parameter)
-        if len(mandatory_params) < 1:
-            # TODO:coverage: we don't have any tests for invalid constraint components
-            raise ConstraintLoadError(
-                "A sh:ConstraintComponent must have at least one non-optional parameter.",
-                "https://www.w3.org/TR/shacl/#constraint-components-parameters",
-            )
-        self.append(mandatory_params + optional_params)
-
-        validator_node_set = set(shacl_graph.graph.objects(node, SH_validator))
-        node_val_node_set = set(shacl_graph.graph.objects(node, SH_nodeValidator))
-        prop_val_node_set = set(shacl_graph.graph.objects(node, SH_propertyValidator))
-        validator_node_set = validator_node_set.difference(node_val_node_set)
-        validator_node_set = validator_node_set.difference(prop_val_node_set)
-        self.append(validator_node_set)
-        self.append(node_val_node_set)
-        self.append(prop_val_node_set)
-        is_sparql_constraint_component = False
-        for s in (validator_node_set, node_val_node_set, prop_val_node_set):
-            for v in s:
-                v_types = set(shacl_graph.graph.objects(v, RDF_type))
-                if SH_SPARQLAskValidator in v_types or SH_SPARQLSelectValidator in v_types:
-                    is_sparql_constraint_component = True
-                    break
-                v_props = set(p[0] for p in shacl_graph.graph.predicate_objects(v))
-                if SH_ask in v_props or SH_select in v_props:
-                    is_sparql_constraint_component = True
-                    break
-                if is_sparql_constraint_component:
-                    raise ConstraintLoadError(
-                        "Found a mix of SPARQL-based validators and non-SPARQL validators on a SPARQLConstraintComponent.",
-                        'https://www.w3.org/TR/shacl/#constraint-components-validators',
-                    )
-        if is_sparql_constraint_component:
-            return SPARQLConstraintComponent(*self)
-        else:
-            return CustomConstraintComponent(*self)
-
-
-class CustomConstraintComponent(object):
-    __slots__: Tuple = ('sg', 'node', 'parameters', 'validators', 'node_validators', 'property_validators')
-
-    if typing.TYPE_CHECKING:
-        sg: ShapesGraph
-        node: Any
-        parameters: List[SHACLParameter]
-        validators: Set
-        node_validators: Set
-        property_validators: Set
-
-    def __new__(cls, shacl_graph: 'ShapesGraph', node, parameters, validators, node_validators, property_validators):
-        self = super(CustomConstraintComponent, cls).__new__(cls)
-        self.sg = shacl_graph
-        self.node = node
-        self.parameters = parameters
-        self.validators = validators
-        self.node_validators = node_validators
-        self.property_validators = property_validators
-        return self
-
-    def make_validator_for_shape(self, shape: 'Shape'):
-        raise NotImplementedError()
+        return violations
 
 
 class SPARQLConstraintComponent(CustomConstraintComponent):
@@ -444,6 +378,11 @@ class SPARQLConstraintComponent(CustomConstraintComponent):
             cls, shacl_graph, node, parameters, validators, node_validators, property_validators
         )
 
+    @property
+    def messages(self):
+        # TODO: allow messages at this SPARQLConstraintComponent level
+        return []
+
     def make_validator_for_shape(self, shape: 'Shape'):
         """
         :param shape:
